@@ -2,11 +2,14 @@
 /* we try to use gengetopt generated file in a C++ program */
 /* we don't use autoconf and automake vars */
 
-#include <iostream.h>
+#include <iostream>
 #include "stdlib.h"
 
 #include "cmdline1.h"
 
+using std::cout;
+using std::endl;
+
 int
 main (int argc, char **argv)
 {
