@@ -23,7 +23,8 @@ struct gengetopt_option
   char * var_arg; /* canonized long_opt + "_arg" = argument var */
   int default_given ; /* if a default is given */
   char * default_string ; /* default value for this option, if string */
-  double default_num ; /* default value for this option, if numeric */
+  char * group_value;
+  int multiple; /* whether this option can be given more than once */
 };
 
 #endif /* _GENGETOPT_GGOS_H */
